@@ -4,11 +4,10 @@ use Mojo::Base 'LinkEmbedder::Link';
 has provider_name => 'AppearIn';
 has provider_url => sub { Mojo::URL->new('https://appear.in') };
 
-sub learn {
-  my ($self, $cb) = @_;
+sub learn_p {
+  my $self = shift;
   my $path = $self->url->path;
-
-  return $self->SUPER::learn($cb) unless @$path == 1;
+  return $self->SUPER::learn_p unless @$path == 1;
 
   $self->{iframe_src} = "https://appear.in/$path->[0]";
   $self->height(390) unless $self->height;
@@ -17,8 +16,7 @@ sub learn {
   $self->template->[1] = 'iframe.html.ep';
   $self->title("Join the room $path->[0]");
 
-  $self->$cb if $cb;
-  return $self;
+  return Mojo::Promise->new->resolve($self);
 }
 
 1;
